# Pyckles
A super lightweight interface to load spectra from the Pickles 1998 catalogue

[![Tests](https://github.com/AstarVienna/Pyckles/actions/workflows/tests.yml/badge.svg)](https://github.com/AstarVienna/Pyckles/actions/workflows/tests.yml)
[![Poetry](https://img.shields.io/endpoint?url=https://python-poetry.org/badge/v0.json)](https://python-poetry.org/)
![dev version](https://img.shields.io/badge/dynamic/toml?url=https%3A%2F%2Fraw.githubusercontent.com%2FAstarVienna%2FPyckles%2Fmain%2Fpyproject.toml&query=%24.project.version&label=dev%20version&color=teal)
![GitHub Release Date](https://img.shields.io/github/release-date/AstarVienna/Pyckles)

[![Documentation Status](https://readthedocs.org/projects/Pyckles/badge/?version=latest)](https://pyckles.readthedocs.io/)
[![codecov](https://codecov.io/gh/AstarVienna/Pyckles/graph/badge.svg)](https://codecov.io/gh/AstarVienna/Pyckles)
[![PyPI - Version](https://img.shields.io/pypi/v/pyckles)](https://pypi.org/project/pyckles/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyckles)

[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

Does nothing more than download a compiled FITS file with all the stellar spectra and allows the user to access these interactively with python.

Documentation can be found at [Read the Docs](https://pyckles.readthedocs.io/)

## Update - more catalogues available!
Pyckles now allows you to access more than just the Pickles stellar spectra.

The following catalogues are available:
* Pickles (1998): Stellar spectra over [0.15, 2.5]um at 5nm resolution
* Brown (2014): Galaxy spectra over [0.01, 30]um at R~50
